# -*- coding:utf-8 -*-

PROJECTNAME = "sc.pfg.brazilianfields"
DEFAULT_ADD_CONTENT_PERMISSION = "PloneFormGen: Add Content"
